@@ -1373,7 +1373,7 @@ class Ui_MainWindow(object):
         self.processCustom=False
 
     def process_custom(self, name):
-        if self.image != None and (self.processSwirl==False):
+        if self.image != None and (self.processSwirl==False and self.processCustom==False):
             self.cleanup_ui()
             movie = QtGui.QMovie("images/loading.gif")
             self.loading_widget = QtWidgets.QLabel(self.centralwidget)
@@ -1392,7 +1392,7 @@ class Ui_MainWindow(object):
             run.start()
 
     def process_swirl(self):
-        if self.image != None and (self.processCustom==False):
+        if self.image != None and (self.processCustom==False and self.processSwirl==False):
             self.cleanup_ui()
             movie = QtGui.QMovie("images/loading.gif")
             self.loading_widget = QtWidgets.QLabel(self.centralwidget)
